# py-kinguserbot
## A stable userbot base library , based on Pyrogram


### Deploying To Heroku ⚙
[![Deploy To Heroku](https://www.herokucdn.com/deploy/button.svg)](https://heroku.com/deploy?template=https://github.com/ToxicCybers/kinguserbot)

## Installation 
'pip install py-kingbot'


## Usage
=> Create folders named `ownerr`, `utilss`, `assistant` and `admins`.<br/>
=> Add your plugins in the `ownerr` folder and others accordingly.<br/>
=> Create a `.env` file with `API_ID`, `API_HASH`, `SESSION`, 
`BOT_TOKEN`, `BOT_USERNAME`,`DBI_URL`,`OWNER_ID`,  `REDIS_URI`, `REDIS_PASSWORD` & 
`LOG_CHANNEL` as mandatory environment variables. 
=> Run `python -m kingbot` to start the bot.<br/>


Made with 💕 by [@TeamDevilCoder](https://t.me/devilcodes_network).

# Credits
* [Dan](https://github.com/delivrance) for [Pyrogram](https://github.com/pyrogram/pyrogram)
* Abhishek -: A humble thanks to you for the graphics